@@ -1,6 +1,11 @@
 package Reddit::Client;
 
-our $VERSION = '1.30'; # 3/21/19 1.30
+# Remember to include new version and date in the docs, or get rid of that 
+# section altogether
+our $VERSION = '1.311'; # 3/27 1.31
+# 1.31 added a bunch of flags to Link, Thing, Comment, SubReddit
+#	   get_user now accepts 'username' as well as 'user'
+# 	   TODO: make this an alias across more functions, like sub/subreddit is
 # 1.30 -added flair_post and flair_user
 # 1.30 -set_post_flair and set_user_flair have been renamed select_post_flair
 # 		 and select_user_flair respectively, to distinguish them from the new 
@@ -8,11 +13,8 @@ our $VERSION = '1.30'; # 3/21/19 1.30
 # 1.293 -added get_web_url to Message
 # 1.292 -added crosspost_parent to Link
 # 1.291 -print_request_on_error was accidentally left on in get_links_by_id
+
 # TODO: make ispost, iscomment and get_type static
-# 1.29  -added is_original_content flag to Link 1/6/19
-# 1.2817-documentation update
-# 1.281 -morecomments get_collapsed args
-# 1.281 -get_collapsed can also return morecomments
 
 $VERSION = eval $VERSION;
 
@@ -675,6 +677,7 @@ sub fetch_links {
         	args     => $args,
         	data     => $query,
     	);
+		#return $result;
 
     	return [
         	map { Reddit::Client::Link->new($self, $_->{data}) } @{$result->{data}{children}} 
@@ -746,6 +749,7 @@ sub get_subreddit_comments {
         	data     => $query,
     	);
 
+		#return $result;
 		#return $result->{data}{children}[0]->{data};
     	return [
         	 map {Reddit::Client::Comment->new($self, $_->{data})} @{$result->{data}{children}} 
@@ -930,7 +934,7 @@ sub get_modmail_raw {
 sub get_user {
     	my ($self, %param) = @_;
 	my $view	= $param{view} || 'overview';
-	my $user	= $param{user} || croak "expected 'user'";
+	my $user	= $param{user} || $param{username} || croak "expected 'user'";
 
 	my $query = $self->set_listing_defaults(%param);
 
@@ -1635,7 +1639,7 @@ Reddit::Client - A Perl wrapper for the Reddit API.
 
 =head1 VERSION
 
-1.30 3/25/19
+1.311 3/30/19
 
 =head1 DESCRIPTION
 
@@ -1662,7 +1666,7 @@ Reddit::Client handles Oauth session management and HTTP communication with Redd
         refresh_token => "refresh_token",
     );
 
-	# Authorization can also be done separately with get_token()
+    # Authorization can also be done separately with get_token()
     
     # Check your inbox
     my $me = $reddit->me();
@@ -1678,7 +1682,7 @@ Reddit::Client handles Oauth session management and HTTP communication with Redd
     # Get posts from a subreddit or multi
     my $posts = $reddit->get_links(subreddit=>'test', limit=>5);
     
-    foreach my $post (@$posts) {
+    for my $post (@$posts) {
         print $post->{is_self} ? $post->{selftext} : $post->{url};
         print $post->get_web_url();
 
@@ -1703,7 +1707,7 @@ Use the app's client id and secret along with your username and password to crea
 
 As of v1.20, Reddit::Client also supports "web" apps. These are apps that can take actions on behalf of any user that grants them permission. (This uses the familiar "SomeRedditApp wants your permission to..." screen.)
 
-While they are fully supported, there is not yet a setup guide, so getting one running is left as an exercise for the reader. You will need a web server, which you will use to direct users to Reddit's authorization page, which will get the user's permission to do whatever the app has asked to do. It will then redirect the user back to the app's redirect URI. This process generates a refresh token, which is a unique string that your app will use to authenticate instead of a username and password. You will probably want to store refresh tokens locally, otherwise you will have to get permission from the user every time the app runs.
+While they are fully supported, there is not yet a setup guide, so getting one running is left as an exercise for the reader. You will need a web server, which you will use to direct users to Reddit's authorization page, where the user will be asked to grant the app permissions. It will then redirect the user back to the app's redirect URI. This process generates a refresh token, which is a unique string that your app will use to authenticate instead of a username and password. You will probably want to store refresh tokens locally, otherwise you will have to get permission from the user every time the app runs.
 
 Documentation for the web app flow can be found at L<https://github.com/reddit-archive/reddit/wiki/OAuth2>.
 
@@ -1878,11 +1882,11 @@ Returns a list of Subreddit objects matching the search string C<$query>. Option
 =item flair_post
 
     flair_post ( subreddit => $subreddit, link_id => $link_id_or_fullname, 
-                 [ text => $text, ] [ css_class => $css_class, ] )
+               [ text => $text, ] [ css_class => $css_class, ] )
 
 Flair a post with arbitrary text and css class. 
 
-`text` and `css_class` are optional. If not provided, they will remove the existing text and/or css class. One advantage of doing this through the API (as opposed to the Reddit website) is that a css class can be applied with no text at all, not even an empty string. This allows you to have automoderator react to a thread or user in ways that are completely invisible to users.
+C<text> and C<css_class> are optional. If not provided, they will remove the existing text and/or css class. One advantage of doing this through the API (as opposed to the Reddit website) is that a css class can be applied with no text at all, not even an empty string. This allows you to have automoderator react to a thread or user in ways that are completely invisible to users.
 
 =over
 
@@ -2228,11 +2232,11 @@ Select flair for a user from among the sub's existing flair templates. C<flair_t
 
 =item set_post_flair
 
-    Deprecated. Use L<select_post_flair|https://metacpan.org/pod/Reddit::Client#select_post_flair> or L<flair_post|https://metacpan.org/pod/Reddit::Client#flair_post>.
+Deprecated. Use L<select_post_flair|https://metacpan.org/pod/Reddit::Client#select_post_flair> or L<flair_post|https://metacpan.org/pod/Reddit::Client#flair_post>.
 
 =item set_user_flair
 
-    Deprecated. Use L<select_user_flair|https://metacpan.org/pod/Reddit::Client#select_user_flair> or L<flair_user|https://metacpan.org/pod/Reddit::Client#flair_user>.
+Deprecated. Use L<select_user_flair|https://metacpan.org/pod/Reddit::Client#select_user_flair> or L<flair_user|https://metacpan.org/pod/Reddit::Client#flair_user>.
 
 =item submit_comment 
 
