@@ -15,12 +15,12 @@ use constant type => "more";
 
 sub get_collapsed_comments {
 	my ($this, %param) = @_;
-	#die "no link_id" unless $this->{link_id};
-	print "link_id: $this->{link_id}";
-	return unless $this->{link_id};
+	my $linkid = $this->{link_id} || $param{link_id} || undef;
+	print "MoreComments::get_collapsed_comments: link_id is required. Normally this should populate on its own. It being undefined could be the sign of an issue elsewhere. You can set it manually by passing in a link_id." unless $linkid;
+	return unless $linkid;
 
 	my %data = (
-		link_id	=> $this->{link_id},
+		link_id	=> $linkid,
 		children=> $this->{children},
 	);
 	$data{sort}	= $param{sort} if $param{sort};
