@@ -8,11 +8,38 @@ use List::Util qw/first/;
 
 # If a field is used by another class it must also be added to that class's 
 # fields
+# Why does adding a field that exists in link but not comment (can_mod_post)
+# break comments but not other types of things, like profiles?
+# because can_mod_post DOES exist for comments. this would get to that field,
+# which was previously ignored, but now it's in BOOL here, so it would try to 
+# set it, but the field didn't exist in Comment, so it would fail.
 our @BOOL_FIELDS = qw/
-	is_self likes clicked saved hidden over_18 over18 edited
-    has_mail has_mod_mail is_mod is_gold was_comment new
-    public_traffic is_employee verified has_verified_email
-	is_original_content
+can_mod_post
+clicked
+edited
+has_mail
+has_mod_mail
+has_verified_email
+hidden
+is_employee
+is_gold
+is_mod
+is_original_content
+is_self
+likes
+locked
+new
+over18
+over_18
+public_traffic
+quarantine
+removed
+saved
+spam
+spoiler
+stickied
+verified
+was_comment
 /;
 
 use fields qw/session name id/;
